local L = LibStub("AceLocale-3.0"):GetLocale("Titan", true)
local LB = LibStub("AceLocale-3.0"):GetLocale("TitanPals", true)
local AceConfigDialog = LibStub("AceConfigDialog-3.0")
local AceConfig = LibStub("AceConfig-3.0")
local Dewdrop = nil
if AceLibrary:HasInstance("Dewdrop-2.0") then Dewdrop = AceLibrary("Dewdrop-2.0") end

-- ******************************** Config Panel *******************************

-- **************************************************************************
-- NAME : TitanPanelPals_ConfigUtils(a)
-- DESC : Pull information from .toc for config dialog
-- **************************************************************************
local function TitanPanelPals_ConfigUtils(a)
     if ( a == "GetAuthor" ) then
          return GetAddOnMetadata("TitanPals", "Author") or L["TITAN_NA"];
     elseif ( a == "GetCategory" ) then
          return GetAddOnMetadata("TitanPals", "X-Category") or L["TITAN_NA"];
     elseif ( a == "GetEmail" ) then
          return GetAddOnMetadata("TitanPals", "X-Email") or L["TITAN_NA"];
     elseif ( a == "GetWebsite" ) then
          return GetAddOnMetadata("TitanPals", "X-Website") or L["TITAN_NA"];
     elseif ( a == "GetVersion" ) then
          return tostring(GetAddOnMetadata("TitanPals", "Version")) or L["TITAN_NA"];
     end
end

-- **************************************************************************
-- NAME : optionsPals
-- DESC : this is the root of the config dialog
-- **************************************************************************
local optionsPals = {
     name = "Titan Panel Pals",
     type = "group",
     args = {
          confgendesc = {
               order = 1,
               type = "description",
               name = LB["TITAN_PALS_CONFIG_LABEL"].."\n\n",
               cmdHidden = true
          },
          confinfodesc = {
	       order = 2,
               name = "About",
               type = "group", inline = true,
               args = {
                    confversiondesc = {
                         order = 1,
                         type = "description",			
                         name = "|cffffd700".."Version"..": ".._G["GREEN_FONT_COLOR_CODE"]..TitanPanelPals_ConfigUtils("GetVersion"),
                         cmdHidden = true
                    },
                    confauthordesc = {
                         order = 2,
                         type = "description",
                         name = "|cffffd700".."Author"..": ".."|cffff8c00"..TitanPanelPals_ConfigUtils("GetAuthor"),
                         cmdHidden = true
                    },
                    confcatdesc = {
                         order = 3,
                         type = "description",
                         name = "|cffffd700".."Category"..": ".._G["HIGHLIGHT_FONT_COLOR_CODE"]..TitanPanelPals_ConfigUtils("GetCategory"),
                         cmdHidden = true
                    },
                    confemaildesc = {
                         order = 4,
                         type = "description",
                         name = "|cffffd700".."Email"..": ".._G["HIGHLIGHT_FONT_COLOR_CODE"]..TitanPanelPals_ConfigUtils("GetEmail"),
                         cmdHidden = true
                    },
                    confwebsitedesc = {
                         order = 5,
                         type = "description",
                         name = "|cffffd700".."Website"..": ".._G["HIGHLIGHT_FONT_COLOR_CODE"]..TitanPanelPals_ConfigUtils("GetWebsite"),
                         cmdHidden = true
                    },
               }
          },
          setskinhdear = {
               order = 3,
               type = "header",
               name = LB["TITAN_PALS_CONFIG_SET_HEADER"],
          },
          tooltipshowoffline = {
               name = LB["TITAN_PALS_CONFIG_SHOWOFFLINE"],
               desc = LB["TITAN_PALS_CONFIG_SHOWOFFLINE_DESC"],
               order = 4, type = "toggle",
               get = function() return TitanPals["ShowOffline"]; end,
               set = function()
                    TitanPanelPals_CoreUtils("Toggle", "ShowOffline");
               end,
          },
          tooltipshowignored = {
               name = LB["TITAN_PALS_CONFIG_SHOWIGNORED"],
               desc = LB["TITAN_PALS_CONFIG_SHOWIGNORED_DESC"],
               order = 5, type = "toggle",
               get = function() return TitanPals["ShowIgnored"]; end,
               set = function()
                    TitanPanelPals_CoreUtils("Toggle", "ShowIgnored");
               end,
          },
          tooltipshowclass = {
               name = LB["TITAN_PALS_CONFIG_SHOWCLASS"],
               desc = LB["TITAN_PALS_CONFIG_SHOWCLASS_DESC"],
               order = 6, type = "toggle",
               get = function() return TitanPals["ShowClass"]; end,
               set = function()
                    TitanPanelPals_CoreUtils("Toggle", "ShowClass");
               end,
          },
          tooltipshownote = {
               name = LB["TITAN_PALS_CONFIG_SHOWNOTE"],
               desc = LB["TITAN_PALS_CONFIG_SHOWNOTE_DESC"],
               order = 7, type = "toggle",
               get = function() return TitanPals["ShowNote"]; end,
               set = function()
                    TitanPanelPals_CoreUtils("Toggle", "ShowNote");
               end,
          },
          tooltipshowmem = {
               name = LB["TITAN_PALS_CONFIG_SHOWMEM"],
               desc = LB["TITAN_PALS_CONFIG_SHOWMEM_DESC"],
               order = 8, type = "toggle",
               get = function() return TitanPals["ShowMen"]; end,
               set = function()
                    TitanPanelPals_CoreUtils("Toggle", "ShowMen");
               end,
          },
          tooltipnoalts = {
               name = LB["TITAN_PALS_CONFIG_NOALTS"],
               desc = LB["TITAN_PALS_CONFIG_NOALTS_DESC"],
               order = 9, type = "toggle",
               get = function() return TitanPals["NoAlts"]; end,
               set = function()
                    TitanPanelPals_CoreUtils("Toggle", "NoAlts");
               end,
          },
          tooltipnoalts = {
               name = LB["TITAN_PALS_CONFIG_BANNOR"],
               desc = LB["TITAN_PALS_CONFIG_BANNOR_DESC"],
               order = 9, type = "toggle",
               get = function() return TitanPals["DisplayB"]; end,
               set = function()
                    TitanPanelPals_CoreUtils("Toggle", "DisplayB");
               end,
          },
	  --[[ This block is only enabled when I am working on the plugin ]]--
          debuginfodesc = {
               order = 11,
               name = "Debuging",
               type = "group", inline = true,
	       args = {
                    debugmode = {
                         name = LB["TITAN_PALS_CONFIG_DEBUG"],
                         desc = LB["TITAN_PALS_CONFIG_DEBUG_DESC"],
                         order = 1, type = "toggle", --width = "half",
                         get = function() return TitanPals["Debug"]; end,
                         set = function()
                              TitanPanelPals_CoreUtils("Toggle", "Debug");
                         end,
                    },
                    debugeventmode = {
                         name = LB["TITAN_PALS_CONFIG_DEBUGEVENT"],
                         desc = LB["TITAN_PALS_CONFIG_DEBUGEVENT_DESC"],
                         order = 2, type = "toggle", --width = "half",
                         get = function() return TitanPals["DebugEvent"]; end,
                         set = function()
                              TitanPanelPals_CoreUtils("Toggle", "DebugEvent");
                         end,
                    },
                    debuglogeventmode = {
                         name = LB["TITAN_PALS_CONFIG_DEBUGLOGEVENT"],
                         desc = LB["TITAN_PALS_CONFIG_DEBUGLOGEVENT_DESC"],
                         order = 3, type = "toggle", --width = "half",
                         get = function() return TitanPals["DebugLogEvent"]; end,
                         set = function()
                              TitanPanelPals_CoreUtils("Toggle", "DebugLogEvent");
                         end,
                    },
	       },
	  },
	  --[[]]--
     }
}
-- **************************************************************************
-- NAME : TitanPanelPalsButton_OnLoad()
-- DESC : Registers the plugin upon it loading
-- **************************************************************************
function TitanPanelPalsButton_OnLoad(self)
     self.registry = {
          id = LB["TITAN_PALS_CORE_ID"],
          builtIn = false,
          version = TITAN_VERSION,
          menuText = LB["TITAN_PALS_MENU_TEXT"],
          buttonTextFunction = "TitanPanelPalsButton_GetButtonText";
	  tooltipTitle = LB["TITAN_PALS_TOOLTIP"],
          tooltipCustomFunction = TitanPanelPalsButton_SetTooltip;
          icon = LB["TITAN_PALS_CORE_ARTWORK"],
          iconWidth = 16,
          category = "Information",
          savedVariables = {
	       ShowIcon = 1,
	       ShowLabelText = 1,
          }
     };
     self:RegisterEvent("PLAYER_ENTERING_WORLD");
     self:RegisterEvent("FRIENDLIST_UPDATE");
     self:RegisterEvent("IGNORELIST_UPDATE");
     self:RegisterEvent("VARIABLES_LOADED");
     self:RegisterEvent("PLAYER_REGEN_DISABLED");
     self:RegisterEvent("PLAYER_REGEN_ENABLED");
     --Titan Pals Config
     AceConfig:RegisterOptionsTable("Titan Pals", optionsPals);
     AceConfigDialog:AddToBlizOptions("Titan Pals", LB["TITAN_PALS_CONFIG"], L["TITAN_PANEL"]);
     TitanPanelPals_Init();
end